==========
Orso Tools
==========

Package providing tools for ORSO file types and reflectometry related applications.

Usefull for users but also developers of data reduction.

Currently under development and not considered stable for end-users.

=========
GUI Tools
=========

The package provides two tools that can be started after installation:

- osb: ORSO Sampe Builder, an editor tool to help create YAML code for sample model.
- orso_viewer: ORSO file viewer to vizualize a dataset and explore header information.

============
Installation
============

Create a python >=3.9 environment and install the module via pip:

**$ pip install orso-tools**

Alternative is a windows build that can directly be downloaded from GitHub.